progress.create_progress()

Create a rich progress bar with a custom column layout.

Usage

progress.create_progress(
    *, show_progress=True, add_description=True, columns=None, **kwargs
)

Parameters

show_progress: bool = True

Whether to display the progress bar. If False, the progress bar is created but disabled.

add_description: bool = True

Whether to prepend a text column with the task description to the progress bar. Ignored when columns is provided.

columns: list of str or ProgressColumn = None

Override the default column layout. When set, the columns are used as-is and add_description is ignored.

**kwargs: Any
Additional keyword arguments passed to rich.progress.Progress.

Returns

Progress
A configured rich Progress instance.