utils.get_cache_dir()

Get cache directory with fallback to system cache.

Usage

utils.get_cache_dir(cache_dir=None)

Determines the cache directory to use based on the following priority: 1. Provided cache_dir parameter 2. ‘FREEZEBASE_CACHE’ environment variable 3. System cache directory (via platformdirs)

Parameters

cache_dir: str, Path, or None = None
Path to cache directory. If None, will check the environment variables and fall back to the system cache directory.

Returns

Path
Path to the cache directory to use.

Notes

The system cache location varies by platform:

  • Linux: ~/.cache/freezebase
  • macOS: ~/Library/Caches/freezebase
  • Windows: %LOCALAPPDATA%\freezebase\Cache