vectools.is_z_axis_zero()

Check if the Z axis in a GeoDataFrame is always zero.

Usage

vectools.is_z_axis_zero(gdf)

Parameters

gdf: geopandas.GeoDataFrame
GeoDataFrame containing geometries with potential Z coordinates.

Returns

bool
True if all Z values are zero, False otherwise.

Raises

ValueError

If the geometry does not have a Z axis.

TypeError
If the geometry type is unknown.